# Changelog

## 0.3 - 2019-09-19

* Fix schemas packaging error

## 0.2 - 2019-09-19

* Updated schemas and protocol names in line with Choria changes
* Vendor in a copy of the protocol message schemas

## 0.1 - 2019-09-18

* Initial release